CaptureCommandRunner constructor
CaptureCommandRunner({})
Creates a runner with injectable console output and exit-code handling.
Implementation
CaptureCommandRunner({
String executableName = 'artisanal_capture',
super.out,
super.err,
void Function(int)? setExitCode,
}) : super(
executableName,
'Capture terminal cells and export images without a browser.',
setExitCode: setExitCode,
) {
addCommand(_RenderCommand());
addCommand(
GalleryCommand(
onFailure: () => (setExitCode ?? (value) => exitCode = value)(1),
),
);
}