WidgetCaptureMode enum
Selects the source used by captureWidget.
Values
- view → const WidgetCaptureMode
-
Captures the portable, canonical
WidgetApp.view()output. - renderedFrame → const WidgetCaptureMode
-
Captures the final UV cell frame produced by the production renderer.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WidgetCaptureMode> - A constant List of the values in this enum, in order of their declaration.