CaptureImage class final Capture
A rendered PNG and its frame metadata.
Constructors
Properties
- columns → int
-
Number of captured terminal columns.
final
-
diagnostics
→ List<
String> -
Fidelity diagnostics emitted by a non-strict renderer.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Image height in pixels.
final
- png → Uint8List
-
Read-only encoded PNG bytes.
no setter
- rows → int
-
Number of captured terminal rows.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
Image width in pixels.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toHtml(
{String title = 'Artisanal capture'}) → String - Builds a self-contained, script-free preview of the exact PNG.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited